import { HttpBackend, HttpHeaders, HttpParams } from '@angular/common/http';
import { Observable } from 'rxjs';
import { INGXLoggerMetadata } from '../metadata/imetadata';
import { INGXLoggerConfig } from '../config/iconfig';
import { INGXLoggerServerService } from './iserver.service';
import * as i0 from "@angular/core";
export declare class NGXLoggerServerService implements INGXLoggerServerService {
    protected readonly httpBackend: HttpBackend;
    constructor(httpBackend: HttpBackend);
    /**
     * Transforms an error object into a readable string (taking only the stack)
     * This is needed because JSON.stringify would return "{}"
     * @param err the error object
     * @returns The stack of the error
     */
    protected secureErrorObject(err: Error): string;
    /**
     * Transforms the additional parameters to avoid any json error when sending the data to the server
     * Basically it just replaces unstringifiable object to a string mentioning an error
     * @param additional The additional data to be sent
     * @returns The additional data secured
     */
    protected secureAdditionalParameters(additional: any[]): any[];
    /**
     * Transforms the message so that it can be sent to the server
     * @param message the message to be sent
     * @returns the message secured
     */
    protected secureMessage(message: any): string;
    protected logOnServer<T>(url: string, logContent: T, options: {
        headers?: HttpHeaders;
        reportProgress?: boolean;
        params?: HttpParams;
        responseType?: 'arraybuffer' | 'blob' | 'json' | 'text';
        withCredentials?: boolean;
    }): Observable<T>;
    /**
     * Customise the data sent to the API
     * @param metadata the data provided by NGXLogger
     * @returns the data that will be sent to the API in the body
     */
    protected customiseRequestBody(metadata: INGXLoggerMetadata): any;
    sendToServer(metadata: INGXLoggerMetadata, config: INGXLoggerConfig): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NGXLoggerServerService, [{ optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NGXLoggerServerService>;
}
//# sourceMappingURL=server.service.d.ts.map